<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<META http-equiv="Content-Type" content="text/html; charset=utf-8">
<meta content="kurs counter untuk penukaran mata uang USD, EUR, SGD, HKD, dan lainnya melalui BCA" name="description">
<meta content="kurs, dollar, bca, TC Amex" name="keywords">
        
       	

<noscript>
	<div style=" font-size:14px;position: absolute; width:100%; text-align:center; color:WHITE; padding-top:17px"><strong>Untuk tampilan sempurna aktifkan Javascript pada browser Anda <br/><em>For a better experience on www.bca.co.id, enable JavaScript in your browser</em></strong></div>
</noscript>



<meta charset='utf-8'/>
<!--[if lt IE 9]>
<script src="http://www.bca.co.id/include/js/ie9.js;bcac74bc2732a543f44"></script>
<link rel="stylesheet" type="text/css" media="screen,print" href="/include/css/style_ie.css" />
<![endif]-->
<meta name="alexaVerifyID" content="TQ3yf9so__9MSAL3t_RMRvqGXHA" />
<meta name="google-site-verification" content="_h6nT37IjthebCiWL2BaIbaLCc5ZqfnYfQCupEnh1Qk" />
<link rel="stylesheet" type="text/css" media="screen,print" href="http://www.bca.co.id/include/css/tabs.css;bcab1bcccd7d0fc292b" />
<link rel="stylesheet" type="text/css" media="screen,print" href="http://www.bca.co.id/include/css/accordionmenu.css;bcaf74b974cdc9db860" />
<link rel="shortcut icon" href="/favicon.ico" />
<link rel="stylesheet" type="text/css" media="screen,print" href="http://www.bca.co.id/include/css/tipsy.css;bcaf842927f12657d26" />
<link rel="stylesheet" type="text/css" media="screen,print" href="http://www.bca.co.id/include/css/style.css;bca318daafd8637c1b8" />
<link rel="stylesheet" type="text/css" media="screen,print" href="http://www.bca.co.id/include/css/expand.css;bca2f9fe9e349713316" />
<link rel="stylesheet" type="text/css" media="screen,print" href="http://www.bca.co.id/include/css/myslide.css;bca06db61cbf61e5325" />
<link rel="stylesheet" type="text/css" media="screen"  href="http://www.bca.co.id/include/css/colorbox.css;bca5576704f9be2b30b"/>

<link rel="stylesheet" type="text/css" media="screen"  href="http://www.bca.co.id/include/css/survei/survei.css;bca60141b6ebbd1e1d7"/>


<!--12 Feb 14, Mjd //////////SURVEI////////////////-->
  
	<div id="slideout">
		<img src="http://www.bca.co.id/include/images/survei.png;bca8affd2b4c1f721e8" alt="Feedback" id="survey" />
		<div id="slideout_inner">
			<form>
				 <p>Partisipasi Anda akan sangat membantu dalam meningkatkan layanan kami.</p>
				 <p><b><a href="/id/about/sosial-media-bca/survei.html" class="popup_survei link cboxElement">Lanjut</a></b></p>
			</form>
		</div>
	</div>


<!--/////////////SURVEI/////////////////-->                                
        
        <meta content="text/html; charset=utf-8" http-equiv="Content-Type">
<title>Kurs Counter BCA</title>
</head>
<body>
<div class="content">
	            

<div class="header" align="left">
   

 	<a href="/">
        
		<img alt="" src="http://www.bca.co.id/include/images/logo.jpg;bca0fd074ffbcb976d9" />
    
	</a>


</div> 
            
            
            <div class="menu">
                <!-- MENU HORIZONTAL-->
                
                
<div class="menuleft" style="position:absolute;top:147px;width:650px">
    
            <a href="/id/individual/individual.jsp" style="float:left;">Individual</a> 
            <a href="/id/commercial-business/commercial.jsp" style="float:left;">Commercial/Business</a> 
            <a href="/id/corporate/corporate.jsp" style="float:left;">Corporate</a> 
            <a href="/id/about/about_bca_landing.jsp" style="float:left;">About BCA</a> 
</div>
 <!-- END MENU HORIZONTAL--> <!-- SEARCH --> 
    <div class="menuright">
    <form action="/id/search/search_landing.jsp" method="post">
        <table cellpadding="0" cellspacing="0">
            <tr>
                <td>
                    <a href="/id/halo_bca/contact-us_landing.jsp">
                        <img alt="" src="http://www.bca.co.id/include/images/logo_halobca.gif;bcaf35bd46a8c9dfa16" style="margin-right:5px;" class="bcatipsy" title="021-500888 dari ponsel Anda" />
                    </a>
                </td>
                <td>
                    <input type="text" name="query" class="search" value="Search Here" onclick="this.value='';" onfocus="this.select()" onblur="this.value=!this.value?'Search Here':this.value;" />
                </td>
                <td>
                    <input type="submit" class="searchsubmit" value="" />
                </td>
            </tr>
        </table>
    </form>
	</div>

                
                <!-- END SEARCH -->
                <div class="clear"></div>
            </div>
            
            <div class="innercontent">
                
	                	<!-- LEFT MENU -->
		                <div style="width:199px;float:left;min-height:500px">
			                
            <ul id="accordion">
        
 <li> <div> 
                <a href="/id/biaya-limit/tabungan/tabungan_landing.jsp" class="topaccordionmenu" rel="topaccordionmenu">Simpanan</a> 
 </div> 
 </li> 
 <li> <div> 
                <a href="/id/biaya-limit/kartu-kredit/kartu-kredit_landing.jsp" class="topaccordionmenu" rel="topaccordionmenu">Kartu Kredit</a> 
 </div> 
 </li> 
 <li> <div> 
                <a href="/id/biaya-limit/layanan-investasi/layanan-investasi_landing.jsp" class="topaccordionmenu" rel="topaccordionmenu">Layanan Investasi</a> 
 </div> 
 </li> 
 <li> <div> 
                <a href="/id/biaya-limit/layanan-perbankan/layanan-perbankan_landing.jsp" class="topaccordionmenu" rel="topaccordionmenu">Layanan Perbankan</a> 
 </div> 
 </li> 
 <li> <div> 
                <a href="/id/biaya-limit/e-banking/e-banking_landing.jsp" class="topaccordionmenu" rel="topaccordionmenu">e-Banking</a> 
 </div> 
 </li> 
 <li> <div> 
                <a href="/id/biaya-limit/sbdk/sbdk_landing.jsp" class="topaccordionmenu" rel="topaccordionmenu">SBDK</a> 
 </div> 
 </li> 
 <li> <div> 
                <a href="/id/biaya-limit/suku-bunga/suku-bunga_landing.jsp" class="topaccordionmenu" rel="topaccordionmenu">Suku Bunga</a> 
 </div> 
 </li> 
 <li> <div> 
                <a href="/id/biaya-limit/kurs_counter_bca/kurs_counter_bca_landing.jsp" class="topaccordionmenu" rel="topaccordionmenu">Kurs</a> 
 </div> 
 </li> 
 </ul> 
<input id="showmenu" type="hidden" value="998"/>

		                </div>		                
		                <!-- END LEFT MENU -->
		            
	            <div class="contentright" style="padding-left: 3px;min-height:650px;">
	
	<div id="content_top_bar">
		<div id="klikbca">
	<a href="http://www.klikbca.com"> <img
		src="http://www.bca.co.id/include/images/gotobca2.jpg;bca24488b3e24189ba2"
		border="0" />
	</a>
</div>


<div id="breadcrumb">
    
                <span class="breadcrumb_prev" title="Biaya & Tarif">Biaya & Tarif</span> 
            <img alt="" class="breadcrumb_arrow" src="/include/images/breadcrumb_arrow.png" width="11" height="13"/>
        
            <span class="breadcrumb_next" title="Kurs">Kurs</span> 
</div>
		<div style="clear: both;"></div>
	</div>	
	
	<div style="margin:0px 0px; padding-top:10px;">        		        	
        		 



<div style="float:left;margin-left:10px;padding: 10px;width:700px;padding-bottom:40px;min-height:220px;">
    
	<table width="100" border="1" style="float:left;">
        <tr bgcolor="#d7d7d7" style="text-align:center;" height="48px">
			<td><strong><br/>Mata Uang<br/></strong></td>
        </tr>
		
		
		
        <tr>
		<td style="text-align:center;">USD</td> </tr>	
        <tr>
		<td style="text-align:center;">SGD</td> </tr>	
        <tr>
		<td style="text-align:center;">EUR</td> </tr>	
        <tr>
		<td style="text-align:center;">AUD</td> </tr>	
        <tr>
		<td style="text-align:center;">DKK</td> </tr>	
        <tr>
		<td style="text-align:center;">SEK</td> </tr>	
        <tr>
		<td style="text-align:center;">CAD</td> </tr>	
        <tr>
		<td style="text-align:center;">CHF</td> </tr>	
        <tr>
		<td style="text-align:center;">NZD</td> </tr>	
        <tr>
		<td style="text-align:center;">GBP</td> </tr>	
        <tr>
		<td style="text-align:center;">HKD</td> </tr>	
        <tr>
		<td style="text-align:center;">JPY</td> </tr>	
        <tr>
		<td style="text-align:center;">SAR</td> </tr>	
        <tr>
		<td style="text-align:center;">CNY</td> </tr>	
            
    </table>
		<table style="width:200px;float:left;" border="1">
        <tbody>
            <tr bgcolor="#d7d7d7" height="30px" align="center" valign="middle">
                <td width="50%" colspan="2">
                    <strong>e-Rate</strong>
                    <br />
                    <div align="center">17 Feb 2014 / 16:10 WIB</div></td>
                </td>
            </tr>

            <tr bgcolor="#dee9f2" style="text-align:center;" height="15px">
                <td><strong>Jual</strong></td>
                <td><strong>Beli</strong></td>
            </tr>
            
            
        <tr>
            <!-- kolom dua -->
			
            <td style="text-align:right;">11805.0</td>
            <td style="text-align:right;">11755.0</td> </tr> 
        <tr>
            <!-- kolom dua -->
			
            <td style="text-align:right;">9371.25</td>
            <td style="text-align:right;">9321.25</td> </tr> 
        <tr>
            <!-- kolom dua -->
			
            <td style="text-align:right;">16189.8</td>
            <td style="text-align:right;">16109.8</td> </tr> 
        <tr>
            <!-- kolom dua -->
			
            <td style="text-align:right;">10678.83</td>
            <td style="text-align:right;">10608.83</td> </tr> 
        <tr>
            <!-- kolom dua -->
			
            <td style="text-align:right;">2199.25</td>
            <td style="text-align:right;">2129.25</td> </tr> 
        <tr>
            <!-- kolom dua -->
			
            <td style="text-align:right;">1864.39</td>
            <td style="text-align:right;">1794.39</td> </tr> 
        <tr>
            <!-- kolom dua -->
			
            <td style="text-align:right;">10770.45</td>
            <td style="text-align:right;">10700.45</td> </tr> 
        <tr>
            <!-- kolom dua -->
			
            <td style="text-align:right;">13249.44</td>
            <td style="text-align:right;">13179.44</td> </tr> 
        <tr>
            <!-- kolom dua -->
			
            <td style="text-align:right;">9891.92</td>
            <td style="text-align:right;">9821.92</td> </tr> 
        <tr>
            <!-- kolom dua -->
			
            <td style="text-align:right;">19784.47</td>
            <td style="text-align:right;">19704.47</td> </tr> 
        <tr>
            <!-- kolom dua -->
			
            <td style="text-align:right;">1529.0</td>
            <td style="text-align:right;">1509.0</td> </tr> 
        <tr>
            <!-- kolom dua -->
			
            <td style="text-align:right;">117.17</td>
            <td style="text-align:right;">114.17</td> </tr> 
        <tr>
            <!-- kolom dua -->
			
            <td style="text-align:right;">3176.06</td>
            <td style="text-align:right;">3106.06</td> </tr> 
        <tr>
            <!-- kolom dua -->
			
            <td style="text-align:right;">1962.62</td>
            <td style="text-align:right;">1922.62</td> </tr> 
            
        </tbody>
    </table>
	<table style="width:200px;float:left;" border="1">
        <tbody>
            <tr bgcolor="#d7d7d7" height="30px" align="center" valign="middle">
                <td width="50%" colspan="2">
                    <strong>TT Counter</strong>
                    <br />
                    <div align="center">17 Feb 2014 / 16:09 WIB</div>
                </td>
            </tr>

            <tr bgcolor="#dee9f2" style="text-align:center;" height="15px">
                <td><strong>Jual</strong></td>
                <td><strong>Beli</strong></td>
            </tr>
            
            
                    <tr>
                        <td style="text-align:right;">11930.00</td>
                        <td style="text-align:right;">11630.00</td> <!-- kolom dua --> </tr> 
                    <tr>
                        <td style="text-align:right;">9392.00</td>
                        <td style="text-align:right;">9292.00</td> <!-- kolom dua --> </tr> 
                    <tr>
                        <td style="text-align:right;">16380.30</td>
                        <td style="text-align:right;">15932.30</td> <!-- kolom dua --> </tr> 
                    <tr>
                        <td style="text-align:right;">10804.25</td>
                        <td style="text-align:right;">10485.25</td> <!-- kolom dua --> </tr> 
                    <tr>
                        <td style="text-align:right;">2211.25</td>
                        <td style="text-align:right;">2129.45</td> <!-- kolom dua --> </tr> 
                    <tr>
                        <td style="text-align:right;">1870.70</td>
                        <td style="text-align:right;">1798.40</td> <!-- kolom dua --> </tr> 
                    <tr>
                        <td style="text-align:right;">10896.30</td>
                        <td style="text-align:right;">10571.30</td> <!-- kolom dua --> </tr> 
                    <tr>
                        <td style="text-align:right;">13416.70</td>
                        <td style="text-align:right;">13034.70</td> <!-- kolom dua --> </tr> 
                    <tr>
                        <td style="text-align:right;">10016.85</td>
                        <td style="text-align:right;">9693.85</td> <!-- kolom dua --> </tr> 
                    <tr>
                        <td style="text-align:right;">20030.30</td>
                        <td style="text-align:right;">19457.30</td> <!-- kolom dua --> </tr> 
                    <tr>
                        <td style="text-align:right;">1531.20</td>
                        <td style="text-align:right;">1505.10</td> <!-- kolom dua --> </tr> 
                    <tr>
                        <td style="text-align:right;">117.73</td>
                        <td style="text-align:right;">113.72</td> <!-- kolom dua --> </tr> 
                    <tr>
                        <td style="text-align:right;">3192.10</td>
                        <td style="text-align:right;">3090.10</td> <!-- kolom dua --> </tr> 
                    <tr>
                        <td style="text-align:right;">1971.40</td>
                        <td style="text-align:right;">1914.20</td> <!-- kolom dua --> </tr> 
            
        </tbody>
    </table>
    <table width="200" border="1" style="float:left;">
        <tr bgcolor="#d7d7d7" height="30px" align="center" valign="middle">
            <td colspan="2"><strong>Bank Notes</strong> <br />
                <div align="center">17 Feb 2014 / 10:22 WIB</div></td>
        </tr>
        <tr bgcolor="#dee9f2" style="text-align:center;" height="15px">
            <td><strong>Jual</strong></td>
            <td><strong>Beli</strong></td>
        </tr>
        
        
        <tr>
            <!-- kolom dua -->
            <td style="text-align:right;">11825.00</td>
            <td style="text-align:right;">11525.00</td> </tr> 
        <tr>
            <!-- kolom dua -->
            <td style="text-align:right;">9399.00</td>
            <td style="text-align:right;">9146.00</td> </tr> 
        <tr>
            <!-- kolom dua -->
            <td style="text-align:right;">16232.00</td>
            <td style="text-align:right;">15773.00</td> </tr> 
        <tr>
            <!-- kolom dua -->
            <td style="text-align:right;">10737.00</td>
            <td style="text-align:right;">10408.00</td> </tr> 
        <tr>
            <!-- kolom dua -->
            <td style="text-align:right;">2191.00</td>
            <td style="text-align:right;">2086.00</td> </tr> 
        <tr>
            <!-- kolom dua -->
            <td style="text-align:right;">1849.00</td>
            <td style="text-align:right;">1749.00</td> </tr> 
        <tr>
            <!-- kolom dua -->
            <td style="text-align:right;">10801.00</td>
            <td style="text-align:right;">10459.00</td> </tr> 
        <tr>
            <!-- kolom dua -->
            <td style="text-align:right;">13289.00</td>
            <td style="text-align:right;">12897.00</td> </tr> 
        <tr>
            <!-- kolom dua -->
            <td style="text-align:right;">9919.00</td>
            <td style="text-align:right;">9608.00</td> </tr> 
        <tr>
            <!-- kolom dua -->
            <td style="text-align:right;">19899.00</td>
            <td style="text-align:right;">19320.00</td> </tr> 
        <tr>
            <!-- kolom dua -->
            <td style="text-align:right;">1532.00</td>
            <td style="text-align:right;">1475.00</td> </tr> 
        <tr>
            <!-- kolom dua -->
            <td style="text-align:right;">116.76</td>
            <td style="text-align:right;">113.13</td> </tr> 
        <tr>
            <!-- kolom dua -->
            <td style="text-align:right;">3157.00</td>
            <td style="text-align:right;">2923.00</td> </tr> 
        <tr>
            <!-- kolom dua -->
            <td style="text-align:right;">1956.00</td>
            <td style="text-align:right;">1886.00</td> </tr> 
        
    </table><br />
	<table>
		<tr>
    		<td>
				<font face="Verdana" size="2" color="#ff0000"><b>Catatan :</b></font><br />
				<font face="Verdana" size="2" color="#ff0000">Kurs e-Rate digunakan untuk transaksi melalui e-Channel</font><br />
           	</td>
       	</tr>
        <tr>
            <td><br/>
            	<span style="font-size:10px">*) Hubungi cabang BCA terdekat untuk rnendapatkan informasi kurs khusus 
   				untuk transaksi dengan nilai nominal tertentu.<br /><br />

				Kurs dapat berubah tanpa pemberitahuan terlebih dahulu.<br /><br />
				</span>
            </td>
      	</tr>
 	</table>

    <div class="clear"></div>
	<!--</div>
<div class="clear"></div>
<div style="margin-left:10px"><br /><br />
<table border="0" cellpadding="5px" cellspacing="1px" width="100%">
<tbody>
<tr bgcolor="#d7d7d7" height="25px" align="center"> 
<td rowspan="2"> <strong>Mata Uang</strong></td>
<td colspan="2"> <strong>TC VISA BCA</strong></td>
<td colspan="2"> <strong>TC AMEX dan NON Visa BCA</strong></td>
</tr>
<tr bgcolor="#d7d7d7" height="25px" align="center"> 
<td><strong>Jual</strong></td>
<td><strong>Beli</strong></td>
<td><strong>Jual</strong></td>
<td><strong>Beli</strong></td>
</tr>
<tr bgcolor="#dee9f2" height="25px" align="center"> 
<td>USD</td>
<td>0.00</td>
<td>9025.00</td>
<td>0.00</td>
<td>8875.00</td>
</tr>
</tbody></table>-->
<br />


</div></div>
                            
            <span style="float:left;margin-right:10px;margin-top:2px;"></span>
            
            </div>
		                
		                <div style="clear:both;"></div>
		                
		                </div>	            
	                 
		                <div class="clear"></div>
		                <!-- FOOTER -->
			            <div id="banner_wrapper">Rekan Perbankan Anda</div>
<div id="banner_wrapper_footer"></div>
<div id="footermenu">
    <p>
        
        <a href="/id/bca-promo/bca-promo_landing.jsp">BCA Promo</a>
		|
        <a href="/id/unduh-form/unduh-form.jsp">Unduh Form</a>		
        |
        <a href="/id/simulasi-pinjaman/simulasi-pinjaman.jsp">Simulasi Pinjaman</a>
        |
        <a href="http://www.klikbca.com/OnlineApplication/online_application.html">Aplikasi Online</a>
        |
        <a href="/id/about/hubungan-investor/laporan-tahunan/laporan_tahunan_landing.jsp">Hubungan Investor</a>
        |
        <a href="/id/biaya-limit/tabungan/tabungan_landing.jsp">Biaya & Tarif</a>
        |
        <a href="/id/network/network_landing.jsp">Lokasi BCA</a>
        
    </p>
</div>
<div id="footer">
	<a href="/id/tips-keamanan/tips-keamanan.jsp">Tips Keamanan Perbankan</a>
    |
    <a href="/id/privacy-policy/privacy-policy_landing.jsp">Kebijakan Privasi</a>
    |
    <a href="/id/syarat-ketentuan/internet_banking/internet-banking_landing.jsp">Syarat &amp; Ketentuan</a>
    |
    <a href="/id/sitemap/sitemap_landing.jsp">Sitemap</a>
    
</div>

<div id="footer">
	<span style="font-size:9px">Copyright (c) 2013 PT Bank Central Asia Tbk, All Rights Reserved</span>
    
</div>
				        <!-- END FOOTER -->
				        <div class="clear"></div>
			         
                </div>
        	
        		     <div id="fl_menu">
    <div id="fl_menu_wrapper">
      <div>
            <a href="/en/individual/individual.jsp"><img alt="" src="http://www.bca.co.id/include/images/icon_float1.jpg;bca4684235ad6e06514" width="17" height="12" class="float_img bcatipsy" title="English" /></a>
        </div> 
        
        <div style="height:1px;background:#bfbfbf;"></div>
     <!--
        <div>
            <a href="/id/faq/topik-umum/personal-loan-korporasi/personal-loan-korporasi_landing.jsp"><img alt="" src="/include/images/icon_float2.png" class="float_img bcatipsy" title="FAQ" /></a>
        </div>
        <div style="height:1px;background:#bfbfbf;"></div> -->
        <div>
            <a href="/id/about/berita/berita_bca.jsp"><img alt="" src="http://www.bca.co.id/include/images/icon_float3.png;bca417c105da6db17ff" width="16" height="16" class="float_img bcatipsy" title="Berita" /></a>
        </div>
        
        <div style="height:1px;background:#bfbfbf;"></div>
        <div>
            <a href="http://www.karirbca.com"><img alt="" src="http://www.bca.co.id/include/images/icon_float5.png;bcabf320b4ce31797f4" width="16" height="24" class="float_img bcatipsy" title="Karir BCA" /></a>
        </div>
        
        <div style="height:1px;background:#bfbfbf;"></div>
        <div>
            <a href="/id/network/network_landing.jsp"><img alt="" src="http://www.bca.co.id/include/images/icon_float4.png;bca3c928bdf23804d36" 
             width="13" height="18"class="float_img bcatipsy" title="Lokasi BCA" /></a>
        </div>
		<div style="height:1px;background:#bfbfbf;"></div>
    </div>
</div>


<script type="text/javascript" language="javascript" src="/include/js/jquery.js"></script>
<script type="text/javascript" language="javascript" src="http://www.bca.co.id/include/js/jquery.tipsy.js;bca11bdd044cec19184"></script>		        
<script type="text/javascript" language="javascript" src="http://www.bca.co.id/include/js/jquery.easing.1.3.js;bca32e48c491b0d8ed7"></script>        
<script type="text/javascript" language="javascript" src="http://www.bca.co.id/include/js/jquery.mousewheel-3.0.4.pack.js;bca10f1b87d14dac131"></script>
<script type="text/javascript" language="javascript" src="http://www.bca.co.id/include/js/script.js;bca6bef1b0424eabe95"></script>        		
<script type="text/javascript" language="javascript" src="http://www.bca.co.id/include/js/jquery.corner.js;bca255ddc67bf812a9b"></script>
<script type="text/javascript" language="javascript" src="http://www.bca.co.id/include/js/virtualpaginate.js;bca813b49971d86e20c"></script>
<script type="text/javascript" language="javascript">            
            $float_speed=1500; //milliseconds
            $float_easing="easeOutQuint";
            $menu_fade_speed=500; //milliseconds
            $closed_menu_opacity=0.75;
			$menu_position=0;
            //cache vars
            $fl_menu=$("#fl_menu");
            $fl_menu_menu=$("#fl_menu .menu");
            $fl_menu_label=$("#fl_menu .label");
			
			var menuPosition = 0;

            $(window).load(function() {
                    menuPosition=$('#fl_menu').position().top;
                    FloatMenu();
					
					//scroll to top
					$('html,body').animate({scrollTop:0}, 'fast');
            });

            $(window).scroll(function () {
                    FloatMenu();
                    //menuPosition=$('#fl_menu').position();
            });

            function FloatMenu(){
                    var scrollAmount=$(document).scrollTop();
                    var newPosition=menuPosition+scrollAmount;
	                    if($(window).height()<$fl_menu.height()+$fl_menu_menu.height()){
	                            $fl_menu.css("top",menuPosition);
	                    } else {
	                            $fl_menu.stop().animate({top: newPosition}, $float_speed, $float_easing);
	                    }
            }

            $('#fl_menu').corner();
		if($('.rounded5').length > 0){
			$('.rounded5').corner('5px');
		}
		if($('.rounded5left').length > 0){
			$('.rounded5left').corner('left 5px');
		}
		if($('.rounded10').length > 0){
			$('.rounded10').corner('10px');
		}
		if($('.rounded10left').length > 0){
			$('.rounded10left').corner('left 10px');
		}
		if($('.rounded10right').length > 0){
			$('.rounded10right').corner('right 10px');
		}
		if($('.round5top').length > 0){
			$('.round5top').corner('top 5px');
		}
		if($('.round5bottom').length > 0){
			$('.round5bottom').corner('top 5px');
		}
            $('#fl_menu_wrapper').corner();
			//$('.box_solusi_untuk_anda').corner();  declare it in content
			//$('.box_kebutuhan_anda_lainnya').corner(); declare in in content
			$('.linktab').corner("top 5px")
            $('.header').corner("top 5px");
            $('.bcatipsy').tipsy({
                    html: true,
                    gravity: $.fn.tipsy.autoNS
            });            
        </script>
         <script type="text/javascript" language="javascript">
      		// start accordion menu  kiri / vertical
//			var showmenu= 0;
		if($('#showmenu').length>0){
			 var showmenu= document.getElementById("showmenu").value;
			  $(document).ready(function () {

                    startList = function() {
                            navRoot = document.getElementById("accordion");
                                    for (i=0; i< navRoot.childNodes.length; i++) {
                                            node = navRoot.childNodes[i];
                                            if (node.nodeName=="li") {
                                                    node.onmouseover=function() {
                                                            this.className+=" over";
                                                    }
                                                    node.onmouseout=function() {
                                                            this.className=this.className.replace(" over", "");
                                                    }
                                            }
                                    }
                    }
                    window.onload=startList;

            });
      		}
           
         
            $(document).ready(function() {
            	
                    $('.submenu').hide();
					
            });                        
                    function toggleMenu(idmenu){
                            $('#menu'+idmenu).toggle(400);
                    }
                    function showMenu(idmenu){
                            $('#menu'+idmenu).show(400);
                    }
                    function hideMenu(idmenu){
                            $('#menu'+idmenu).hide(400);
                    }
            $("#accordion > li > div").click(function(){
                    if(false == $(this).next().is(':visible')) {
                            $('#accordion ul').slideUp(300);
                    }
                    $(this).next().slideToggle(300);
            });
            $('#accordion ul.submainmenu:eq('+showmenu+')').show();
            // end accordion menu kiri
            
            // start accordion content
             $(".accordion_content_wrapper > li > div").click(function(){
           $("a[rel='accordioncontent']").removeClass('accordioncontentOver').addClass('accordioncontent');
           if(false == $(this).next().is(':visible')) { //jika next elemen masih ter-hide
                   $('.accordion_content_wrapper li ul.accordion_content_desc').slideUp(300);
                   $(this).find('a').removeClass('accordioncontent').addClass('accordioncontentOver');
           }else{
                   $(this).find('a').removeClass('accordioncontentOver').addClass('accordioncontent'); 
           }
           $(this).next().slideToggle(300);
       });
	</script>
	
	<!-- CAROUSEL -->
		<script src="/include/js/1.7.2.jquery.min.js" language="javascript" type="text/javascript"></script>
		<script src="http://www.bca.co.id/include/js/jquery.tinycarousel.min.js;bca713f88e18f3dc452" language="javascript" type="text/javascript"></script>
			
		<script type="text/javascript">
		$(document).ready(function(){
			$('#slider1').tinycarousel();
		});
		
				$(document).ready(function(){
			$('#slider2').tinycarousel();	
		});
		
				$(document).ready(function(){
			$('#slider3').tinycarousel();	
		});
		</script>
	
	<!--script src="/include/js/jquery-1.7.1.min.js" language="javascript" type="text/javascript"></script-->
	<script src="http://www.bca.co.id/include/js/ui.core.js;bca563311d1e309f6f1" language="javascript" type="text/javascript"></script>
	<script src="http://www.bca.co.id/include/js/ui.tabs.js;bcadf3f723410b2d77f" language="javascript" type="text/javascript"></script>
	<script src="http://www.bca.co.id/include/js/ui.tabs.paging.js;bca21285d5358f8e0c7" language="javascript" type="text/javascript"></script>
	<script src="http://www.bca.co.id/include/js/expand.js;bcafa2e412ee2c502ed" language="javascript" type="text/javascript"></script>
	<script src="http://www.bca.co.id/include/js/jquery.colorbox-min.js;bcac409b17440019e2c" language="javascript" type="text/javascript"></script>
	
	
	<script language="javascript" type="text/javascript">
	 $(document).ready(function () {
		if($('#tab_paging').length>0){			
	   		$('#tab_paging').tabs();
	   		$('#tab_paging').tabs('paging');	   		
			
		}
		
		
		
		if($('h3.expand').length>0){
	   		$("h3.expand").toggler();
		}
		 if($('.popup').length>0){
            			$('.popup').colorbox({
            				width:"50%",
            				height:"50%",
                			scrolling: true,
                			opacity: 0.6,
                			overlayClose: false
            			});
            			}		
		
		if($('.popup_gtb').length>0){
            			$('.popup_gtb').colorbox({
            				iframe:true,
            				width:"750px",
            				height:"100%",
                			scrolling: true,
                			opacity: 0.6,
                			overlayClose: false                			                		
            			});
           }

	// POPup Untuk FYN
	// Mjd,17 Juni 2013

	if($('.popup_fyn').length>0){
            			$('.popup_fyn').colorbox({
            				iframe:true,
            				width:"970px",
            				height:"600px",
                			scrolling: false,
                			opacity: 0.6,
                			overlayClose: false                			                		
            			});
           }
	// End PopUp FYN
	
	//Popup XPresi, Mjd 12 Des 13
		if($('.popup_xpresi').length>0){
            			$('.popup_xpresi').colorbox({
            				iframe:true,
            				width:"970px",
            				height:"600px",
                			scrolling: true,
                			opacity: 0.6,
                			overlayClose: false                			                		
            			});
        }
	// Internet Survei, Mjd 12 Feb 14

		if($('.popup_survei').length>0){
            			$('.popup_survei').colorbox({
            				width:"750px",
            				height:"40%",
                			scrolling: true,
                			opacity: 0.6,
                			overlayClose: false
            			});
            			}

		if($('.popup_video').length>0){
            			$('.popup_video').colorbox({
            				scrolling: false,
                			opacity: 0.6,
                			overlayClose: false
            			});
            			}
	
		
		
	});
		if($('.kk_item').length>0){			
				var kk=new virtualpaginate({
				            piececlass: "kk_item",
				            piececontainer: 'div', //Let script know you're using "p" tags as separator (instead of default "div")
				            pieces_per_page: 9,
				            defaultpage: 0,
				            wraparound: false,
				            persist: false
				});
				kk.buildpagination(["scriptspaginate"]);
		}
		if($('.kk_item2').length>0){			
			var kk2=new virtualpaginate({
            piececlass: "kk_item2",
            piececontainer: 'div', //Let script know you're using "p" tags as separator (instead of default "div")
            pieces_per_page: 3,
            defaultpage: 0,
            wraparound: false,
            persist: false
        });
        kk2.buildpagination(["paginatekk"]);
	
	}
	function gototab(id){
			if($('#tab_paging').length>0){
				$('#tab_paging').tabs('select', id);
			}
	}
	function open_popup(page,title,width,height){
		w=800;
		h=400;
		
		if (width!=null) {
			w = width;
		}
		if (height!=null) {
			h = height;
		}
		
        window.open(page,title,"menubar=no,width="+w+",height="+h+",toolbar=no,scrollbars=yes");
    	}
	
 	
 	 if($('#chooseyear').val() != ""){
			opencontent();
	 	}


	function opencontent(){
		$(".newswrap").hide();
		$("#"+$('#chooseyear').val()).show();
		$("#yeartitle").html($('#chooseyear').val());
	} 	

	function videochoosed(){
		if($('#videooption').val().length > 0){
			$.colorbox({href:"/include/video/"+$('#videooption').val()+".html"}); 
		}
	}
	
	function apple_videochoosed(){
		if($('#videooption').val().length > 0){
			window.location="/include/video/"+$('#videooption').val()+".mov";
		}
	}
	
	function replaceThousandSep(value){
		return value.replace(/\./g,'');
	}
	
	function replaceThousandSepEn(value){
		return value.replace(/\,/g,'');
	}
		
	</script>

	
<script src="http://www.bca.co.id/include/js/jquery.ui.widget.js;bca14e8535bfe046038" language="javascript" type="text/javascript"></script>
<script src="http://www.bca.co.id/include/js/jquery.ui.mouse.js;bca195f48d82aa7cf9c" language="javascript" type="text/javascript"></script>	
<script src="http://www.bca.co.id/include/js/jquery.ui.draggable.js;bca79e311966fabc706" language="javascript" type="text/javascript"></script>
<script type="text/javascript" language="javascript" src="http://www.bca.co.id/include/js/myslide.js;bca653d3eca98b9e64b"></script>
        <script type="text/javascript" src="http://www.bca.co.id/include/js/jquery.price_format.js;bca091468dc307ba22f"></script>
        <script type="text/javascript">

            $(function(){

                $('.thousandsep').priceFormat({
                    prefix: '',
                    centsLimit: 0,
					centsSeparator: '',
                    thousandsSeparator: '.'
                });
            });
			
			$(function(){

                $('.thousandsep-en').priceFormat({
                    prefix: '',
                    centsLimit: 0,
					centsSeparator: '',
                    thousandsSeparator: ','
                });
            });

        </script>


<!--JS Fyn-->		

<!--<script src="/include/js/fyn/jquery.colorbox.js"></script>-->		
		<script>
			$(document).ready(function(){
				//Examples of how to assign the ColorBox event to elements				
				$(".iframe").colorbox({iframe:true, width:"950", height:"600",scrolling: false,});

			});
		</script>
		
 </body>
</html>
